diff include/Bela.h @ 311:493a07f6ec09 prerelease

Renamed BelaContext->audioSampleCount to BelaContext->audioFramesElapsed for consistency of terminology
author andrewm
date Fri, 27 May 2016 18:37:51 +0100
parents ff5f346a293e
children 00725dfc1b87
line wrap: on
line diff
--- a/include/Bela.h	Fri May 27 18:29:20 2016 +0100
+++ b/include/Bela.h	Fri May 27 18:37:51 2016 +0100
@@ -243,13 +243,13 @@
 	/// Digital sample rate in Hz (currently always 44100.0)
 	const float digitalSampleRate;
 
 	/// \brief Number of elapsed audio samples since the start of rendering.
 	///
 	/// This holds the total number of audio samples as of the beginning of the current period. To
 	/// find the current number of analog or digital samples elapsed, multiply by the ratio of the
 	/// sample rates (e.g. half the number of analog samples will have elapsed if the analog sample
 	/// rate is 22050).
-	const uint64_t audioSampleCount;
+	const uint64_t audioFramesElapsed;
 
 	/// \brief Other audio/sensor settings
 	///
@@ -243,13 +243,13 @@
 	const float digitalSampleRate;
 
-	/// \brief Number of elapsed audio samples since the start of rendering.
+	/// \brief Number of elapsed audio frames since the start of rendering.
 	///
@@ -243,13 +243,13 @@
 	///
-	/// This holds the total number of audio samples as of the beginning of the current period. To
-	/// find the current number of analog or digital samples elapsed, multiply by the ratio of the
-	/// sample rates (e.g. half the number of analog samples will have elapsed if the analog sample
+	/// This holds the total number of audio frames as of the beginning of the current period. To
+	/// find the current number of analog or digital frames elapsed, multiply by the ratio of the
+	/// sample rates (e.g. half the number of analog frames will have elapsed if the analog sample
 	/// rate is 22050).